@@ -1,5 +1,5 @@
 ##
-# Copyright 2012-2019 Ghent University
+# Copyright 2012-2020 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -30,6 +30,7 @@ Intel Math Kernel Library (MKL), and Intel FFTW wrappers).
 :author: Kenneth Hoste (Ghent University)
 """
 from distutils.version import LooseVersion
+import re
 
 from easybuild.toolchains.iimpi import Iimpi
 from easybuild.toolchains.iimkl import Iimkl
@@ -47,11 +48,16 @@ class Intel(Iimpi, IntelMKL, IntelFFTW):
 
     def is_deprecated(self):
         """Return whether or not this toolchain is deprecated."""
+        # need to transform a version like '2016a' with something that is safe to compare with '2016.01'
+        # comparing subversions that include letters causes TypeErrors in Python 3
+        # 'a' is assumed to be equivalent with '.01' (January), and 'b' with '.07' (June) (good enough for this purpose)
+        version = self.version.replace('a', '.01').replace('b', '.07')
+
         # intel toolchains older than intel/2016a are deprecated
         # take into account that intel/2016.x is always < intel/2016a according to LooseVersion;
         # intel/2016.01 & co are not deprecated yet...
-        intel_ver = LooseVersion(self.version)
-        if intel_ver < LooseVersion('2016a') and intel_ver < LooseVersion('2016.01'):
+        # make sure a non-symbolic version (e.g., 'system') is used before making comparisons using LooseVersion
+        if re.match('^[0-9]', version) and LooseVersion(version) < LooseVersion('2016.01'):
             deprecated = True
         else:
             deprecated = False
