@@ -1,5 +1,5 @@
 # #
-# Copyright 2018-2019 Ghent University
+# Copyright 2018-2020 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -36,12 +36,11 @@ from unittest import TextTestRunner
 
 from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.filetools import adjust_permissions, mkdir, read_file, remove_file, which, write_file
-from easybuild.tools.containers.singularity import parse_container_base
 
 
 MOCKED_SINGULARITY = """#!/bin/bash
 if [[ $1 == '--version' ]]; then
-    echo "2.4.0"
+    echo "%(version)s"
 else
     echo "singularity was called with arguments: $@"
     # actually create image file using 'touch'
@@ -73,32 +72,6 @@ fi
 class ContainersTest(EnhancedTestCase):
     """Tests for containers support"""
 
-    def test_parse_container_base(self):
-        """Test parse_container_base function."""
-
-        for base_spec in [None, '']:
-            self.assertErrorRegex(EasyBuildError, "--container-base must be specified", parse_container_base, base_spec)
-
-        # format of base spec must be correct: <bootstrap_agent>:<arg> or <bootstrap_agent>:<arg1>:<arg2>
-        error_regex = "Invalid format for --container-base"
-        for base_spec in ['foo', 'foo:bar:baz:sjee']:
-            self.assertErrorRegex(EasyBuildError, error_regex, parse_container_base, base_spec)
-
-        # bootstrap agent must be known
-        error_regex = "Bootstrap agent in container base spec must be one of: docker, localimage, shub"
-        self.assertErrorRegex(EasyBuildError, error_regex, parse_container_base, 'foo:bar')
-
-        # check parsing of 'localimage' base spec
-        expected = {'bootstrap_agent': 'localimage', 'arg1': '/path/to/base.img'}
-        self.assertEqual(parse_container_base('localimage:/path/to/base.img'), expected)
-
-        # check parsing of 'docker' and 'shub' base spec (2nd argument, image tag, is optional)
-        for agent in ['docker', 'shub']:
-            expected = {'bootstrap_agent': agent, 'arg1': 'foo'}
-            self.assertEqual(parse_container_base('%s:foo' % agent), expected)
-            expected.update({'arg2': 'bar'})
-            self.assertEqual(parse_container_base('%s:foo:bar' % agent), expected)
-
     def run_main(self, args, raise_error=True):
         """Helper function to run main with arguments specified in 'args' and return stdout/stderr."""
         self.mock_stdout(True)
@@ -117,8 +90,8 @@ class ContainersTest(EnhancedTestCase):
             regex = re.compile(regex, re.M)
             self.assertTrue(regex.search(stdout), "Pattern '%s' found in: %s" % (regex.pattern, stdout))
 
-    def test_end2end_singularity_recipe(self):
-        """End-to-end test for --containerize (recipe only)."""
+    def test_end2end_singularity_recipe_config(self):
+        """End-to-end test for --containerize (recipe only), using --container-config."""
         test_ecs = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'easyconfigs', 'test_ecs')
         toy_ec = os.path.join(test_ecs, 't', 'toy', 'toy-0.0.eb')
 
@@ -127,76 +100,166 @@ class ContainersTest(EnhancedTestCase):
         # --containerpath must be an existing directory (this is done to avoid misconfiguration)
         mkdir(containerpath)
 
+        test_container_recipe = os.path.join(self.test_prefix, 'containers', 'Singularity.toy-0.0')
+
         args = [
             toy_ec,
             '--containerize',
             '--experimental',
         ]
 
-        error_pattern = "--container-base must be specified"
+        args.extend(['--container-config', 'osversion=7.6.1810'])
+        error_pattern = r"Keyword 'bootstrap' is required in container base config"
         self.assertErrorRegex(EasyBuildError, error_pattern, self.run_main, args, raise_error=True)
 
-        # generating Singularity definition file with 'docker' or 'shub' bootstrap agents always works,
-        # i.e. image label is not verified, image tag can be anything
-        for cont_base in ['docker:test123', 'docker:test123:foo', 'shub:test123', 'shub:test123:foo']:
-            stdout, stderr = self.run_main(args + ['--container-base=%s' % cont_base])
-
-            self.assertFalse(stderr)
-            regexs = ["^== Singularity definition file created at %s/containers/Singularity.toy-0.0" % self.test_prefix]
-            self.check_regexs(regexs, stdout)
-
-            remove_file(os.path.join(self.test_prefix, 'containers', 'Singularity.toy-0.0'))
-
-        args.append("--container-base=shub:test123")
-        self.run_main(args)
-
-        # existing definition file is not overwritten without use of --force
-        error_pattern = "Container recipe at .* already exists, not overwriting it without --force"
+        args.extend(['--container-config', 'bootstrap=foobar'])
+        error_pattern = r"Unknown value specified for 'bootstrap' keyword: foobar \(known: arch, busybox, debootstrap, "
         self.assertErrorRegex(EasyBuildError, error_pattern, self.run_main, args, raise_error=True)
 
-        stdout, stderr = self.run_main(args + ['--force'])
-        self.assertFalse(stderr)
-        regexs = [
-            "^== WARNING: overwriting existing container recipe at .* due to --force",
-            "^== Singularity definition file created at %s/containers/Singularity.toy-0.0" % self.test_prefix,
+        # default mirror URL for yum bootstrap agent uses ${OSVERSION}, so 'osversion' must be specified too
+        args.extend(['--container-config', 'bootstrap=yum'])
+        error_pattern = "Keyword 'osversion' is required in container base config when '%{OSVERSION}' is used"
+        self.assertErrorRegex(EasyBuildError, error_pattern, self.run_main, args, raise_error=True)
+
+        args[-1] = 'bootstrap=yum,osversion=7.6.1810'
+        stdout, stderr = self.run_main(args, raise_error=True)
+
+        txt = read_file(test_container_recipe)
+        expected = '\n'.join([
+            "Bootstrap: yum",
+            "OSVersion: 7.6.1810",
+            "MirrorURL: http://mirror.centos.org/centos-%{OSVERSION}/%{OSVERSION}/os/x86_64/",
+            "Include: yum",
+            '\n',
+        ])
+        self.assertTrue(txt.startswith(expected), "Container recipe starts with '%s':\n\n%s" % (expected, txt))
+
+        # when installing from scratch, a bunch of OS packages are installed too
+        pkgs = ['epel-release', 'python', 'setuptools', 'Lmod', r'gcc-c\+\+', 'make', 'patch', 'tar']
+        for pkg in pkgs:
+            regex = re.compile(r"^yum install .*%s" % pkg, re.M)
+            self.assertTrue(regex.search(txt), "Pattern '%s' found in: %s" % (regex.pattern, txt))
+
+        pip_patterns = [
+            # EasyBuild and dependencies are installed with pip by default
+            "pip install -U setuptools",
+            "pip install.*vsc-base",
+            "pip install easybuild",
         ]
-        self.check_regexs(regexs, stdout)
-
-        remove_file(os.path.join(self.test_prefix, 'containers', 'Singularity.toy-0.0'))
-
-        # add another easyconfig file to check if multiple easyconfigs are handled correctly
-        args.insert(1, os.path.join(test_ecs, 'g', 'GCC', 'GCC-4.9.2.eb'))
-
-        # with 'localimage' bootstrap agent, specified image must exist
-        test_img = os.path.join(self.test_prefix, 'test123.img')
-        args[-1] = "--container-base=localimage:%s" % test_img
-        error_pattern = "Singularity base image at specified path does not exist"
-        self.assertErrorRegex(EasyBuildError, error_pattern, self.run_main, args, raise_error=True)
-
-        write_file(test_img, '')
-        stdout, stderr = self.run_main(args)
-        self.assertFalse(stderr)
-        regexs = ["^== Singularity definition file created at %s/containers/Singularity.toy-0.0" % self.test_prefix]
-        self.check_regexs(regexs, stdout)
-
-        # check contents of generated recipe
-        def_file = read_file(os.path.join(self.test_prefix, 'containers', 'Singularity.toy-0.0'))
-        regexs = [
-            "^Bootstrap: localimage$",
-            "^From: %s$" % test_img,
-            "^eb toy-0.0.eb GCC-4.9.2.eb",
-            "module load toy/0.0 GCC/4.9.2$",
+        post_commands_patterns = [
+            # easybuild user is added if it doesn't exist yet
+            r"id easybuild \|\| useradd easybuild",
+            # /app and /scratch are created (if missing) by default
+            r"if \[ ! -d /app \]; then mkdir -p /app",
+            r"if \[ ! -d /scratch \]; then mkdir -p /scratch",
         ]
-        self.check_regexs(regexs, def_file)
+        eb_pattern = r"eb toy-0.0.eb --robot\s*$"
+        for pattern in pip_patterns + post_commands_patterns + [eb_pattern]:
+            regex = re.compile('^' + pattern, re.M)
+            self.assertTrue(regex.search(txt), "Pattern '%s' found in: %s" % (regex.pattern, txt))
 
-        # image extension must make sense when localimage is used
-        for img_name in ['test123.foo', 'test123']:
-            test_img = os.path.join(self.test_prefix, img_name)
-            args[-1] = "--container-base=localimage:%s" % test_img
-            write_file(test_img, '')
-            error_pattern = "Invalid image extension '.*' must be \.img or \.simg"
+        remove_file(test_container_recipe)
+
+        # can also specify a custom mirror URL
+        args[-1] += ',mirrorurl=https://example.com'
+        stdout, stderr = self.run_main(args, raise_error=True)
+
+        txt = read_file(test_container_recipe)
+        expected = '\n'.join([
+            "Bootstrap: yum",
+            "OSVersion: 7.6.1810",
+            "MirrorURL: https://example.com",
+            "Include: yum",
+            '\n',
+        ])
+        self.assertTrue(txt.startswith(expected), "Container recipe starts with '%s':\n\n%s" % (expected, txt))
+
+        remove_file(test_container_recipe)
+
+        # osversion is not required when %{OSVERSION} is nost used in mirror URL
+        args[-1] = 'bootstrap=yum,mirrorurl=https://example.com,include=test123'
+        stdout, stderr = self.run_main(args, raise_error=True)
+
+        txt = read_file(test_container_recipe)
+        expected = '\n'.join([
+            "Bootstrap: yum",
+            "MirrorURL: https://example.com",
+            "Include: test123",
+            '\n',
+        ])
+        self.assertTrue(txt.startswith(expected), "Container recipe starts with '%s':\n\n%s" % (expected, txt))
+
+        # also check with image-based bootstrap agent, which requires 'from'
+        test_cases = [
+            ('docker', 'test'),
+            ('localimage', 'test.simg'),
+            ('library', 'sylabsed/examples/lolcow:latest'),
+            ('shub', 'test'),
+        ]
+        error_pattern = "Keyword 'from' is required in container base config when using bootstrap agent"
+        for (bootstrap, from_spec) in test_cases:
+            args[-1] = 'bootstrap=%s' % bootstrap
             self.assertErrorRegex(EasyBuildError, error_pattern, self.run_main, args, raise_error=True)
 
+            args[-1] += ',from=%s' % from_spec
+            remove_file(test_container_recipe)
+            stdout, stderr = self.run_main(args, raise_error=True)
+
+            txt = read_file(test_container_recipe)
+            expected = '\n'.join([
+                "Bootstrap: %s" % bootstrap,
+                "From: %s" % from_spec,
+                '',
+            ])
+            self.assertTrue(txt.startswith(expected), "Container recipe starts with '%s':\n\n%s" % (expected, txt))
+
+            # no OS packages are installed by default when starting from an existing image
+            self.assertFalse("yum install" in txt)
+
+            for pattern in pip_patterns + post_commands_patterns + [eb_pattern]:
+                regex = re.compile('^' + pattern, re.M)
+                self.assertTrue(regex.search(txt), "Pattern '%s' found in: %s" % (regex.pattern, txt))
+
+        remove_file(test_container_recipe)
+
+        # commands to install EasyBuild can be customized via 'eb_install' keyword
+        args[-1] = 'bootstrap=yum,osversion=7.6.1810,install_eb=easy_install easybuild'
+        stdout, stderr = self.run_main(args, raise_error=True)
+        txt = read_file(test_container_recipe)
+
+        for pattern in pip_patterns:
+            regex = re.compile('^' + pattern, re.M)
+            self.assertFalse(regex.search(txt), "Pattern '%s' should not be found in: %s" % (regex.pattern, txt))
+
+        for pattern in ["easy_install easybuild", eb_pattern]:
+            regex = re.compile('^' + pattern, re.M)
+            self.assertTrue(regex.search(txt), "Pattern '%s' should be found in: %s" % (regex.pattern, txt))
+
+        remove_file(test_container_recipe)
+
+        # post commands be be customized via 'post_commands' keyword
+        args[-1] = 'bootstrap=yum,osversion=7.6.1810,post_commands=id easybuild'
+        stdout, stderr = self.run_main(args, raise_error=True)
+        txt = read_file(test_container_recipe)
+
+        for pattern in post_commands_patterns:
+            regex = re.compile('^' + pattern, re.M)
+            self.assertFalse(regex.search(txt), "Pattern '%s' should not be found in: %s" % (regex.pattern, txt))
+
+        for pattern in ["id easybuild", eb_pattern]:
+            regex = re.compile('^' + pattern, re.M)
+            self.assertTrue(regex.search(txt), "Pattern '%s' should be found in: %s" % (regex.pattern, txt))
+
+        remove_file(test_container_recipe)
+
+        # options can be passed to 'eb' command in recipe via 'eb_args' keyword
+        args[-1] = 'bootstrap=yum,osversion=7.6.1810,eb_args=--debug -l'
+        stdout, stderr = self.run_main(args, raise_error=True)
+        txt = read_file(test_container_recipe)
+
+        regex = re.compile(r"^eb toy-0.0.eb --robot --debug -l", re.M)
+        self.assertTrue(regex.search(txt), "Pattern '%s' should be found in: %s" % (regex.pattern, txt))
+
     def test_end2end_singularity_image(self):
         """End-to-end test for --containerize (recipe + image)."""
         topdir = os.path.dirname(os.path.abspath(__file__))
@@ -214,7 +277,7 @@ class ContainersTest(EnhancedTestCase):
             toy_ec,
             '-C',  # equivalent with --containerize
             '--experimental',
-            '--container-base=localimage:%s' % test_img,
+            '--container-config=bootstrap=localimage,from=%s' % test_img,
             '--container-build-image',
         ]
 
@@ -224,7 +287,7 @@ class ContainersTest(EnhancedTestCase):
 
         # install mocked versions of 'sudo' and 'singularity' commands
         singularity = os.path.join(self.test_prefix, 'bin', 'singularity')
-        write_file(singularity, MOCKED_SINGULARITY)
+        write_file(singularity, '')  # placeholder
         adjust_permissions(singularity, stat.S_IXUSR, add=True)
 
         sudo = os.path.join(self.test_prefix, 'bin', 'sudo')
@@ -233,31 +296,39 @@ class ContainersTest(EnhancedTestCase):
 
         os.environ['PATH'] = os.path.pathsep.join([os.path.join(self.test_prefix, 'bin'), os.getenv('PATH')])
 
-        stdout, stderr = self.run_main(args)
-        self.assertFalse(stderr)
-        regexs = [
-            "^== singularity tool found at %s/bin/singularity" % self.test_prefix,
-            "^== singularity version '2.4.0' is 2.4 or higher ... OK",
-            "^== Singularity definition file created at %s/containers/Singularity\.toy-0.0" % self.test_prefix,
-            "^== Running 'sudo\s*\S*/singularity build\s*/.* /.*', you may need to enter your 'sudo' password...",
-            "^== Singularity image created at %s/containers/toy-0.0\.simg" % self.test_prefix,
-        ]
-        self.check_regexs(regexs, stdout)
+        for (version, ext) in [('2.4.0', 'simg'), ('3.1.0', 'sif')]:
+            write_file(singularity, MOCKED_SINGULARITY % {'version': version})
 
-        self.assertTrue(os.path.exists(os.path.join(containerpath, 'toy-0.0.simg')))
+            stdout, stderr = self.run_main(args)
+            self.assertFalse(stderr)
+            regexs = [
+                r"^== singularity tool found at %s/bin/singularity" % self.test_prefix,
+                r"^== singularity version '%s' is 2.4 or higher ... OK" % version,
+                r"^== Singularity definition file created at %s/containers/Singularity\.toy-0.0" % self.test_prefix,
+                r"^== Running 'sudo\s*\S*/singularity build\s*/.* /.*', you may need to enter your 'sudo' password...",
+                r"^== Singularity image created at %s/containers/toy-0.0\.%s" % (self.test_prefix, ext),
+            ]
+            self.check_regexs(regexs, stdout)
 
-        remove_file(os.path.join(containerpath, 'Singularity.toy-0.0'))
+            self.assertTrue(os.path.exists(os.path.join(containerpath, 'toy-0.0.%s' % ext)))
+
+            remove_file(os.path.join(containerpath, 'Singularity.toy-0.0'))
 
         # check use of --container-image-format & --container-image-name
+        write_file(singularity, MOCKED_SINGULARITY % {'version': '2.4.0'})
         args.extend([
             "--container-image-format=ext3",
             "--container-image-name=foo-bar",
         ])
         stdout, stderr = self.run_main(args)
         self.assertFalse(stderr)
-        regexs[-3] = "^== Singularity definition file created at %s/containers/Singularity\.foo-bar" % self.test_prefix
-        regexs[-2] = "^== Running 'sudo\s*\S*/singularity build --writable /.* /.*', you may need to enter .*"
-        regexs[-1] = "^== Singularity image created at %s/containers/foo-bar\.img$" % self.test_prefix
+        regexs = [
+            r"^== singularity tool found at %s/bin/singularity" % self.test_prefix,
+            r"^== singularity version '2.4.0' is 2.4 or higher ... OK",
+            r"^== Singularity definition file created at %s/containers/Singularity\.foo-bar" % self.test_prefix,
+            r"^== Running 'sudo\s*\S*/singularity build --writable /.* /.*', you may need to enter .*",
+            r"^== Singularity image created at %s/containers/foo-bar\.img$" % self.test_prefix,
+        ]
         self.check_regexs(regexs, stdout)
 
         cont_img = os.path.join(containerpath, 'foo-bar.img')
@@ -310,34 +381,34 @@ class ContainersTest(EnhancedTestCase):
             '--experimental',
         ]
 
-        error_pattern = "Unsupported container base image 'not-supported'"
+        error_pattern = "Unsupported container config 'not-supported'"
         self.assertErrorRegex(EasyBuildError,
                               error_pattern,
                               self.run_main,
-                              base_args + ['--container-base=not-supported'],
+                              base_args + ['--container-config=not-supported'],
                               raise_error=True)
 
         for cont_base in ['ubuntu:16.04', 'centos:7']:
-            stdout, stderr = self.run_main(base_args + ['--container-base=%s' % cont_base])
+            stdout, stderr = self.run_main(base_args + ['--container-config=%s' % cont_base])
             self.assertFalse(stderr)
             regexs = ["^== Dockerfile definition file created at %s/containers/Dockerfile.toy-0.0" % self.test_prefix]
             self.check_regexs(regexs, stdout)
             remove_file(os.path.join(self.test_prefix, 'containers', 'Dockerfile.toy-0.0'))
 
-        self.run_main(base_args + ['--container-base=centos:7'])
+        self.run_main(base_args + ['--container-config=centos:7'])
 
         error_pattern = "Container recipe at %s/containers/Dockerfile.toy-0.0 already exists, " \
                         "not overwriting it without --force" % self.test_prefix
         self.assertErrorRegex(EasyBuildError,
                               error_pattern,
                               self.run_main,
-                              base_args + ['--container-base=centos:7'],
+                              base_args + ['--container-config=centos:7'],
                               raise_error=True)
 
         remove_file(os.path.join(self.test_prefix, 'containers', 'Dockerfile.toy-0.0'))
 
         base_args.insert(1, os.path.join(test_ecs, 'g', 'GCC', 'GCC-4.9.2.eb'))
-        self.run_main(base_args + ['--container-base=ubuntu:16.04'])
+        self.run_main(base_args + ['--container-config=ubuntu:16.04'])
         def_file = read_file(os.path.join(self.test_prefix, 'containers', 'Dockerfile.toy-0.0'))
         regexs = [
             "FROM ubuntu:16.04",
@@ -346,6 +417,11 @@ class ContainersTest(EnhancedTestCase):
         ]
         self.check_regexs(regexs, def_file)
 
+        # there should be no leading/trailing whitespace included
+        for pattern in [r'^\s+', r'\s+$']:
+            regex = re.compile(pattern)
+            self.assertFalse(regex.search(def_file), "Pattern '%s' should *not* be found in: %s" % (pattern, def_file))
+
     def test_end2end_docker_image(self):
 
         topdir = os.path.dirname(os.path.abspath(__file__))
@@ -361,7 +437,7 @@ class ContainersTest(EnhancedTestCase):
             '-C',  # equivalent with --containerize
             '--experimental',
             '--container-type=docker',
-            '--container-base=ubuntu:16.04',
+            '--container-config=ubuntu:16.04',
             '--container-build-image',
         ]
 
@@ -395,6 +471,45 @@ class ContainersTest(EnhancedTestCase):
         self.assertFalse(stderr)
         self.check_regexs(regexs, stdout)
 
+    def test_container_config_template_recipe(self):
+        """Test use of --container-config and --container-template-recipe."""
+        tmpl_path = os.path.join(self.test_prefix, 'tmpl.txt')
+        tmpl_txt = '\n'.join([
+            "# this is just a test",
+            "bootstrap: %(bootstrap)s",
+            "from: %(from)s",
+            '',
+            '%%post',
+            "eb %(easyconfigs)s --robot --debug -l",
+        ])
+        write_file(tmpl_path, tmpl_txt)
+        args = [
+            '--experimental',
+            '--containerize',
+            '--container-template-recipe=%s' % tmpl_path,
+            'toy-0.0.eb',
+        ]
+        error_pattern = "--container-config must be specified!"
+        self.assertErrorRegex(EasyBuildError, error_pattern, self.run_main, args)
+
+        args.extend(['--container-config', 'bootstrap=localimage,from=foobar'])
+        stdout, stderr = self.run_main(args)
+
+        self.assertFalse(stderr)
+        regex = re.compile("^== Singularity definition file created at .*/containers/Singularity.toy-0.0$")
+        self.assertTrue(regex.match(stdout), "Stdout matches pattern '%s': %s" % (regex.pattern, stdout))
+
+        expected = '\n'.join([
+            "# this is just a test",
+            "bootstrap: localimage",
+            "from: foobar",
+            "",
+            "%post",
+            "eb toy-0.0.eb --robot --debug -l",
+        ])
+        cont_recipe = read_file(os.path.join(self.test_prefix, 'containers', 'Singularity.toy-0.0'))
+        self.assertEqual(cont_recipe, expected)
+
 
 def suite():
     """ returns all the testcases in this module """
@@ -402,4 +517,5 @@ def suite():
 
 
 if __name__ == '__main__':
-    TextTestRunner(verbosity=1).run(suite())
+    res = TextTestRunner(verbosity=1).run(suite())
+    sys.exit(len(res.failures))
